
//*******************************************************************
//********** Toscope : Osciloscopio para Unix Sound System **********
//*******************************************************************
//***** Txino - Enero 1998 ******************************************
//*******************************************************************

#include "defs.h"


//************* Algunos valores por defecto *****************

#define DEFAULT_OSCOPE_RATE      44000
#define DEFAULT_OSCOPE_CHANNELS  2
#define DEFAULT_OSCOPE_BPS       8
#define DEFAULT_OSCOPE_FRAGMENT_SIZE  1024

#define DEFAULT_OSCOPE_TRIG_LEVEL  10

#define DEFAULT_OSCOPE_DEV "/dev/dsp"

//***********************************************************


typedef enum{ OSCOPE_NO_TRIG=0, OSCOPE_ASC_TRIG=1, OSCOPE_DESC_TRIG=2 } OSCOPE_TRIG_TYPE;


//***********************************************************

class oscope_dev     //**** INTERFAZ MULTITAREA *********
{
  int fragment_size;
  int rate;          // Frecuencia.
  int bps;           // Bits Por Sample.
  int channels;      // N de canales.
  int dma_sub;       // Eso mismo.

  OSCOPE_TRIG_TYPE trig_mode;	// Tipo de disparo.
  int trig_level;		// Nivel de disparo.
  int trig_chan;		// Canal que realiza el disparo.
  int trig_pos;			// Posicin del disparo en el fragment.
  
  int scanline_size;   		// Tamao de la linea de barrido (<BUF_SIZE)

  int dev_h;			// Handle del dispositivo abierto.

  void check_status(int status);
  void flush_dev();

  void crea(int r,int b,int c);
  void destruye() { if (buffer!=NULL) delete(buffer); close_dev(); }

public:

  byte *buffer;      // Puntero al Buffer.
  
  oscope_dev(int r=DEFAULT_OSCOPE_RATE,int b=DEFAULT_OSCOPE_BPS,
	     int c=DEFAULT_OSCOPE_CHANNELS)
   {
     buffer=NULL;
     crea(r,b,c);
   }
    
  ~oscope_dev() { destruye(); }

  //************************************

  boolean open_dev();
  void reset_dev();
  void close_dev();
  
  void set_rate(int rate);
  int get_rate() { return rate; }
  float get_dt() { return 1.0/rate; }

  int get_chan() { return channels; }
  int get_bps() { return bps; }
  int get_fragment_size() { return fragment_size; }

  int get_scanline_size() { return scanline_size; }


  void set_trig_mode(OSCOPE_TRIG_TYPE tm)
   {
     trig_mode=tm;
   }
  OSCOPE_TRIG_TYPE get_trig_mode() { return trig_mode; }
  
  void set_trig_level(int tl)
   {
     trig_level=tl+128;
   }
  int get_trig_level() { return trig_level; }

  void set_trig_chan(int tc) 
   {
     trig_chan=tc;
   }
  int get_trig_chan() { return trig_chan; }
  
  boolean read_frame();              

  float get_sample(int chan,int n);

};



//***********************************************************************


